[Lldb-commits] [lldb] r130773 - in /lldb/trunk/test/stop-hook: TestStopHook.py TestStopHookMechanism.py

Johnny Chen johnny.chen at apple.com
Tue May 3 11:40:19 PDT 2011


Author: johnny
Date: Tue May  3 13:40:19 2011
New Revision: 130773

URL: http://llvm.org/viewvc/llvm-project?rev=130773&view=rev
Log:
Rename TestStopHook.py to the more appropriate TestStopHookMechanism.py, and update the docstrings.

Added:
    lldb/trunk/test/stop-hook/TestStopHookMechanism.py
      - copied, changed from r130767, lldb/trunk/test/stop-hook/TestStopHook.py
Removed:
    lldb/trunk/test/stop-hook/TestStopHook.py

Removed: lldb/trunk/test/stop-hook/TestStopHook.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/stop-hook/TestStopHook.py?rev=130772&view=auto
==============================================================================
--- lldb/trunk/test/stop-hook/TestStopHook.py (original)
+++ lldb/trunk/test/stop-hook/TestStopHook.py (removed)
@@ -1,90 +0,0 @@
-"""
-Test lldb target stop-hook command.
-"""
-
-import os
-import unittest2
-import lldb
-import pexpect
-from lldbtest import *
-
-class StopHookTestCase(TestBase):
-
-    mydir = "stop-hook"
-
-    @unittest2.skipUnless(sys.platform.startswith("darwin"), "requires Darwin")
-    def test_with_dsym(self):
-        """Test a sequence of target add-hook commands."""
-        self.buildDsym()
-        self.stop_hook_command_sequence()
-
-    def test_with_dwarf(self):
-        """Test a sequence of target add-hook commands."""
-        self.buildDwarf()
-        self.stop_hook_command_sequence()
-
-    def setUp(self):
-        # Call super's setUp().
-        TestBase.setUp(self)
-        # Find the line numbers inside main.cpp.
-        self.begl = line_number('main.cpp', '// Set breakpoint here to test target stop-hook.')
-        self.endl = line_number('main.cpp', '// End of the line range for which stop-hook is to be run.')
-        self.line = line_number('main.cpp', '// Another breakpoint which is outside of the stop-hook range.')
-
-    def stop_hook_command_sequence(self):
-        """Test a sequence of target stop-hook commands."""
-        exe = os.path.join(os.getcwd(), "a.out")
-        prompt = "(lldb) "
-        add_prompt = "Enter your stop hook command(s).  Type 'DONE' to end.\r\n> "
-        add_prompt1 = "\r\n> "
-
-        # So that the child gets torn down after the test.
-        self.child = pexpect.spawn('%s %s' % (self.lldbExec, exe))
-        child = self.child
-        # Turn on logging for what the child sends back.
-        if self.TraceOn():
-            child.logfile_read = sys.stdout
-
-        # Set the breakpoint, followed by the target stop-hook commands.
-        child.expect_exact(prompt)
-        child.sendline('breakpoint set -f main.cpp -l %d' % self.begl)
-        child.expect_exact(prompt)
-        child.sendline('breakpoint set -f main.cpp -l %d' % self.line)
-        child.expect_exact(prompt)
-        child.sendline('target stop-hook add -f main.cpp -l %d -e %d' % (self.begl, self.endl))
-        child.expect_exact(add_prompt)
-        child.sendline('expr ptr')
-        child.expect_exact(add_prompt1)
-        child.sendline('DONE')
-        child.expect_exact(prompt)
-        child.sendline('target stop-hook list')
-
-        # Now run the program, expect to stop at the the first breakpoint which is within the stop-hook range.
-        child.expect_exact(prompt)
-        child.sendline('run')
-        child.expect_exact(prompt)
-        child.sendline('thread step-over')
-        #self.DebugPExpect(child)
-        child.expect_exact('** End Stop Hooks **')
-        #self.DebugPExpect(child)
-        # Verify that the 'Stop Hooks' mechanism is fired off.
-        self.expect(child.before, exe=False,
-            substrs = ['(void *) $0 = 0x'])
-
-        # Now continue the inferior, we'll stop at another breakpoint which is outside the stop-hook range.
-        child.sendline('process continue')
-        child.expect_exact(prompt)
-        #self.DebugPExpect(child)
-        child.sendline('thread step-over')
-        child.expect_exact(prompt)
-        #self.DebugPExpect(child)
-        # Verify that the 'Stop Hooks' mechanism is NOT BEING fired off.
-        self.expect(child.before, exe=False, matching=False,
-            substrs = ['(void *) $0 = 0x'])
-        
-
-if __name__ == '__main__':
-    import atexit
-    lldb.SBDebugger.Initialize()
-    atexit.register(lambda: lldb.SBDebugger.Terminate())
-    unittest2.main()

Copied: lldb/trunk/test/stop-hook/TestStopHookMechanism.py (from r130767, lldb/trunk/test/stop-hook/TestStopHook.py)
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/stop-hook/TestStopHookMechanism.py?p2=lldb/trunk/test/stop-hook/TestStopHookMechanism.py&p1=lldb/trunk/test/stop-hook/TestStopHook.py&r1=130767&r2=130773&rev=130773&view=diff
==============================================================================
--- lldb/trunk/test/stop-hook/TestStopHook.py (original)
+++ lldb/trunk/test/stop-hook/TestStopHookMechanism.py Tue May  3 13:40:19 2011
@@ -1,5 +1,5 @@
 """
-Test lldb target stop-hook command.
+Test lldb target stop-hook mechanism to see whether it fires off correctly .
 """
 
 import os
@@ -8,20 +8,20 @@
 import pexpect
 from lldbtest import *
 
-class StopHookTestCase(TestBase):
+class StopHookMechanismTestCase(TestBase):
 
     mydir = "stop-hook"
 
     @unittest2.skipUnless(sys.platform.startswith("darwin"), "requires Darwin")
     def test_with_dsym(self):
-        """Test a sequence of target add-hook commands."""
+        """Test the stop-hook mechanism."""
         self.buildDsym()
-        self.stop_hook_command_sequence()
+        self.stop_hook_firing()
 
     def test_with_dwarf(self):
-        """Test a sequence of target add-hook commands."""
+        """Test the stop-hook mechanism."""
         self.buildDwarf()
-        self.stop_hook_command_sequence()
+        self.stop_hook_firing()
 
     def setUp(self):
         # Call super's setUp().
@@ -31,8 +31,8 @@
         self.endl = line_number('main.cpp', '// End of the line range for which stop-hook is to be run.')
         self.line = line_number('main.cpp', '// Another breakpoint which is outside of the stop-hook range.')
 
-    def stop_hook_command_sequence(self):
-        """Test a sequence of target stop-hook commands."""
+    def stop_hook_firing(self):
+        """Test the stop-hook mechanism."""
         exe = os.path.join(os.getcwd(), "a.out")
         prompt = "(lldb) "
         add_prompt = "Enter your stop hook command(s).  Type 'DONE' to end.\r\n> "





More information about the lldb-commits mailing list